#include <jlog/jlog.hpp>

// Writing custom wrappers for jlog is super easy!
void coollog(std::vector<jlog::token> tokens) {
    std::vector<jlog::token> wtokens;
    auto group = jlog::token{.content = "COOLLOGGER"};
    wtokens.push_back(group);
    wtokens.insert(wtokens.end(), tokens.begin(), tokens.end());
    jlog::log(wtokens);
}

// We can either define custom logging macros or redefine jlog's builtin macros.
#define COOLINFO(i) coollog(jlog::info_format(i));
#define COOLINFOTRACE(i) coollog(jlog::info_detailed_format(i, FUNCTION, __FILE__, __LINE__));

int main()
{
    LOGLEVEL(jlog::severity::debug); // <- see jlog::severity for full list of log levels

    INFO("This is barely useful information.");
    DEBUG("Debugging Information");
    VERBOSE("Yadda Yadda Yadda");
    WARNING("Slight miscalculation!");
    ERROR("Oops, something went wrong.");
    FATAL("Unrecoverable Error!!!");

    COOLINFO("This is really cool!!!");
    COOLINFOTRACE("THIS IS EVEN COOLER!!!");

    return 0;
}

//Windows :(
#ifdef _WIN32
extern "C" {
    int wmain(int argc, wchar_t* argv[]) {
        return main();
    }
}
#endif